==> haskell-time-compat-1.9.2.2-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: time-compat
version: 1.9.2.2
id: time-compat-1.9.2.2-LEycyZCy3wu2PetPD3qhd5
key: time-compat-1.9.2.2-LEycyZCy3wu2PetPD3qhd5
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Ashley Yakeley
homepage: https://github.com/phadej/time-compat
synopsis: Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.
    .
    /TODO:/
    .
    * Difference type @ParseTime@ and @FormatTime@ instances are missing.
    .
    * Formatting varies depending on underlying @time@ version
    .
    * @dayFractionToTimeOfDay@ on extreme values
category: Time, Compatibility
abi: d980f6bbff72841ed028ea1428edd625
exposed: True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat
hidden-modules: Data.Format Data.Time.Calendar.Private
                Data.Time.Orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/time-compat-1.9.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/time-compat-1.9.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/time-compat-1.9.2.2
hs-libraries: HStime-compat-1.9.2.2-LEycyZCy3wu2PetPD3qhd5
depends:
    base-4.12.0.0 base-orphans-0.8.1-HeyTAcy4PKhDcGhjvJwDzq
    deepseq-1.4.4.0 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html: /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-compat-1.9.2.2-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: time-compat
version: 1.9.2.2
id: time-compat-1.9.2.2-EKNycbtwZG1E2L9BrHYlhu
key: time-compat-1.9.2.2-EKNycbtwZG1E2L9BrHYlhu
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Ashley Yakeley
homepage: https://github.com/phadej/time-compat
synopsis: Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.
    .
    /TODO:/
    .
    * Difference type @ParseTime@ and @FormatTime@ instances are missing.
    .
    * Formatting varies depending on underlying @time@ version
    .
    * @dayFractionToTimeOfDay@ on extreme values
category: Time, Compatibility
abi: 85d0b1cc2101b8b79afee555e920c4b5
exposed: True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat
hidden-modules: Data.Format Data.Time.Calendar.Private
                Data.Time.Orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/time-compat-1.9.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/time-compat-1.9.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/time-compat-1.9.2.2
hs-libraries: HStime-compat-1.9.2.2-EKNycbtwZG1E2L9BrHYlhu
depends:
    base-4.12.0.0 base-orphans-0.8.1-ADx13UE5kNMLP8OA0gQSRH
    deepseq-1.4.4.0 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html: /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
